##-----------------------------LICENSE NOTICE------------------------------------
##  This file is part of CPCtelera: An Amstrad CPC Game Engine 
##  Copyright (C) 2018 ronaldo / Fremos / Cheesetea / ByteRealms (@FranGallegoBR)
##
##  This program is free software: you can redistribute it and/or modify
##  it under the terms of the GNU Lesser General Public License as published by
##  the Free Software Foundation, either version 3 of the License, or
##  (at your option) any later version.
##
##  This program is distributed in the hope that it will be useful,
##  but WITHOUT ANY WARRANTY; without even the implied warranty of
##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##  GNU Lesser General Public License for more details.
##
##  You should have received a copy of the GNU Lesser General Public License
##  along with this program.  If not, see <http://www.gnu.org/licenses/>.
##------------------------------------------------------------------------------
############################################################################
##                        CPCTELERA ENGINE                                ##
##                 Automatic image conversion file                        ##
##------------------------------------------------------------------------##
## This file is intended for users to automate image conversion from JPG, ##
## PNG, GIF, etc. into C-arrays.                                          ##
############################################################################

##
## NEW MACROS
##

## 16 colours palette


## Default values
#$(eval $(call IMG2SP, SET_MODE        , 0                  ))  { 0, 1, 2 }
#$(eval $(call IMG2SP, SET_MASK        , none               ))  { interlaced, none }
#$(eval $(call IMG2SP, SET_FOLDER      , src/               ))
#$(eval $(call IMG2SP, SET_EXTRAPAR    ,                    ))
#$(eval $(call IMG2SP, SET_IMG_FORMAT  , sprites            ))	{ sprites, zgtiles, screen }
#$(eval $(call IMG2SP, SET_OUTPUT      , c                  ))  { bin, c }
#$(eval $(call IMG2SP, SET_PALETTE_FW  , $(PALETTE)         ))
#$(eval $(call IMG2SP, CONVERT_PALETTE , $(PALETTE), g_palette ))
#$(eval $(call IMG2SP, CONVERT         , img.png , w, h, array, palette, tileset))

##
## OLD MACROS (For compatibility)
##

## Example firmware palette definition as variable in cpct_img2tileset format
#define PAL_HARD_0 0x54    //negro
#define PAL_HARD_1 0x5C    //rojo
#define PAL_HARD_2 0x56    //verde
#define PAL_HARD_3 0x5E    //amarillo
#define PAL_HARD_4 0x44    //azul
#define PAL_HARD_5 0x58    //magenta
#define PAL_HARD_6 0x46    //cyan
#define PAL_HARD_7 0x4E    //naranja

#define PAL_HARD_8 0x40    //gris
#define PAL_HARD_9 0x4C    //rojo brillo
#define PAL_HARD_10 0x52   //verde brillo
#define PAL_HARD_11 0x4A   //amarillo brillo
#define PAL_HARD_12 0x55   //azul brillo
#define PAL_HARD_13 0x4D   //magenta brillo
#define PAL_HARD_14 0x53   //cyan brillo
#define PAL_HARD_15 0x4B   //blanco
#PALETTE={0 3 9 12 1 4 10 15 13 6 18 24 2 8 20 26}

#PALETTE={0 13}
## AUTOMATED IMAGE CONVERSION EXAMPLE (Uncomment EVAL line to use)
##
##    This example would convert img/example.png into src/example.{c|h} files.
##    A C-array called pre_example[24*12*2] would be generated with the definition
##    of the image example.png in mode 0 screen pixel format, with interlaced mask.
##    The palette used for conversion is given through the PALETTE variable and
##    a pre_palette[16] array will be generated with the 16 palette colours as 
##	  hardware colour values.

#$(eval $(call IMG2SPRITES,img/example.png,0,pre,24,12,$(PALETTE),mask,src/,hwpalette))
#$(eval $(call IMG2SPRITES,asset/tileset.png,0,gra,4,8,$(PALETTE),zgtiles,src/,hwpalette))

#$(eval $(call IMG2SPRITES,asset/luces/luzDer.png,2,pre,16,24,$(PALETTE),,src/,hwpalette))
#$(eval $(call IMG2SPRITES,asset/luces/luzIzq.png,2,pre,16,24,$(PALETTE),,src/,hwpalette))
#$(eval $(call IMG2SPRITES,asset/luces/luzArr.png,2,pre,16,24,$(PALETTE),,src/,hwpalette))
#$(eval $(call IMG2SPRITES,asset/luces/luzAba.png,2,pre,16,24,$(PALETTE),,src/,hwpalette))
#$(eval $(call IMG2SPRITES,asset/luces/luzDerArr.png,2,pre,16,24,$(PALETTE),,src/,hwpalette))
#$(eval $(call IMG2SPRITES,asset/luces/luzDerAba.png,2,pre,16,24,$(PALETTE),,src/,hwpalette))
#$(eval $(call IMG2SPRITES,asset/luces/luzIzqArr.png,2,pre,16,24,$(PALETTE),,src/,hwpalette))
#$(eval $(call IMG2SPRITES,asset/luces/luzIzqAba.png,2,pre,16,24,$(PALETTE),,src/,hwpalette))
#$(eval $(call IMG2SPRITES,asset/luces/luzFarola.png,2,pre,16,24,$(PALETTE),,src/,hwpalette))

############################################################################
##              DETAILED INSTRUCTIONS AND PARAMETERS                      ##
##------------------------------------------------------------------------##
##                                                                        ##
## Macro used for conversion is IMG2SPRITES, which has up to 9 parameters:##
##  (1): Image file to be converted into C sprite (PNG, JPG, GIF, etc)    ##
##  (2): Graphics mode (0,1,2) for the generated C sprite                 ##
##  (3): Prefix to add to all C-identifiers generated                     ##
##  (4): Width in pixels of each sprite/tile/etc that will be generated   ##
##  (5): Height in pixels of each sprite/tile/etc that will be generated  ##
##  (6): Firmware palette used to convert the image file into C values    ##
##  (7): (mask / tileset / zgtiles)                                       ##
##     - "mask":    generate interlaced mask for all sprites converted    ##
##     - "tileset": generate a tileset array with pointers to all sprites ##
##     - "zgtiles": generate tiles/sprites in Zig-Zag pixel order and     ##
##                  Gray Code row order                                   ##
##  (8): Output subfolder for generated .C/.H files (in project folder)   ##
##  (9): (hwpalette)                                                      ##
##     - "hwpalette": output palette array with hardware colour values    ##
## (10): Aditional options (you can use this to pass aditional modifiers  ##
##       to cpct_img2tileset)                                             ##
##                                                                        ##
## Macro is used in this way (one line for each image to be converted):   ##
##  $(eval $(call IMG2SPRITES,(1),(2),(3),(4),(5),(6),(7),(8),(9), (10))) ##
##                                                                        ##
## Important:                                                             ##
##  * Do NOT separate macro parameters with spaces, blanks or other chars.##
##    ANY character you put into a macro parameter will be passed to the  ##
##    macro. Therefore ...,src/sprites,... will represent "src/sprites"   ##
##    folder, whereas ...,  src/sprites,... means "  src/sprites" folder. ##
##                                                                        ##
##  * You can omit parameters but leaving them empty. Therefore, if you   ##
##  wanted to specify an output folder but do not want your sprites to    ##
##  have mask and/or tileset, you may omit parameter (7) leaving it empty ##
##     $(eval $(call IMG2SPRITES,imgs/1.png,0,g,4,8,$(PAL),,src/))        ##
############################################################################
